==> lra-proxy-api-5.9.10.Final-sources.jar: io/narayana/lra/client/internal/proxy/nonjaxrs/LRAParticipantRegistry.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2019, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package io.narayana.lra.client.internal.proxy.nonjaxrs;

import java.util.HashMap;
import java.util.Map;

/**
 * This class is tracking individual collected LRA participants that
 * contain one or more non-JAX-RS participant methods in their definitions.
 */
public class LRAParticipantRegistry {

    private final Map<String, LRAParticipant> lraParticipants;

    // required for Weld to be able to create proxy
    LRAParticipantRegistry() {
        lraParticipants = new HashMap<>();
    }

    LRAParticipantRegistry(Map<String, LRAParticipant> lraParticipants) {
        this.lraParticipants = new HashMap<>(lraParticipants);
    }

    public LRAParticipant getParticipant(String id) {
            return lraParticipants.get(id);
    }
}

==> lra-proxy-api-5.10.5.Final-sources.jar: io/narayana/lra/client/internal/proxy/nonjaxrs/LRAParticipantRegistry.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2019, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package io.narayana.lra.client.internal.proxy.nonjaxrs;

import java.util.HashMap;
import java.util.Map;

/**
 * This class is tracking individual collected LRA participants that
 * contain one or more non-JAX-RS participant methods in their definitions.
 */
public class LRAParticipantRegistry {

    private final Map<String, LRAParticipant> lraParticipants;

    // required for Weld to be able to create proxy
    public LRAParticipantRegistry() {
        lraParticipants = new HashMap<>();
    }

    LRAParticipantRegistry(Map<String, LRAParticipant> lraParticipants) {
        this.lraParticipants = new HashMap<>(lraParticipants);
    }

    public LRAParticipant getParticipant(String id) {
            return lraParticipants.get(id);
    }
}
